Flask-Pony
==========

|PyPI| |LICENCE| |STARS|

PonyORM for your Flask application.


Documentation
-------------

Read the Russian documentation `here <https://flask-pony.readthedocs.io/ru/latest>`_.

    **Note**.
    My English is very bad, so the documentation is in Russian =) If my package is really useful to someone, then I will be happy for any help with the translation.


.. |PyPI| image:: https://img.shields.io/pypi/v/flask-pony.svg
   :target: https://pypi.python.org/pypi/flask-pony/
   :alt: Latest Version

.. |LICENCE| image:: https://img.shields.io/github/license/kyzima-spb/flask-pony.svg
   :target: https://github.com/kyzima-spb/flask-pony/blob/master/LICENSE
   :alt: Apache 2.0

.. |STARS| image:: https://img.shields.io/github/stars/kyzima-spb/flask-pony.svg
   :target: https://github.com/kyzima-spb/flask-pony/stargazers
